=======================================
File Manipulation Utilities for Tendril
=======================================

.. image:: https://img.shields.io/travis/chintal/tendril-utils-files.svg
        :target: https://travis-ci.org/chintal/tendril-utils-files

.. image:: https://img.shields.io/pypi/v/tendril-utils-files.svg
        :target: https://pypi.python.org/pypi/tendril-utils-files

* License: AGPLv3
* Documentation: http://tendril-utils-files.readthedocs.org


File manipulation utilities for tendril
